function data = generate2class (means,variances,ratio,dim,nSamples)

% generates n-dimensional 2-class data with normal distributions
% dim: dimension of the data
% nSamples:  Cardinality of the dataset
% ratio: Ratio between positive and negative examples 
% means: gaussian means, matrix with size [2,dim]
% variances: gaussian variances, matrix with size [2,dim]

mean1 = means(1,:); %mean of the first gaussian (positive samples)
mean2 = means(2,:); %mean of the second gaussian (negative samples)
var1 = variances(1,:); %variance of the first gaussian (positive samples)
var2 = variances(2,:); %variance of the second gaussian (negative samples)



numPosSamples = round(nSamples*(ratio/(1+ratio)));% number of positive samples
numNegSamples = round(nSamples/(ratio+1));% number of negative samples

%data is a structure with samples and class assignment
samples = repmat(mean1,numPosSamples,1)+repmat(var1,numPosSamples,1).*randn(numPosSamples,dim);
data.samples = [samples; repmat(mean2,numNegSamples,1)+repmat(var2,numNegSamples,1).*randn(numNegSamples,dim)];
data.labels = [ones(numPosSamples,1); zeros(numNegSamples,1)];

%% add outliers

numOutliers = numPosSamples/4;
outliers = repmat(mean2+(mean2-mean1),numOutliers,1)+repmat(var1*2,numOutliers,1).*randn(numOutliers,dim);

data.samples(1:numOutliers,:) = outliers;